@@ -2053,7 +2053,7 @@ bool parseDateTime(const char *&scursor, const char *const send,
 
 namespace {
 
-Headers::Base *extractHeader(const QByteArray &head, const int headerStart, int &endOfFieldBody)
+Headers::Base *extractHeader(QByteArrayView head, const int headerStart, int &endOfFieldBody)
 {
     Headers::Base *header = {};
 
@@ -2093,14 +2093,14 @@ Headers::Base *extractHeader(const QByteArray &head, const int headerStart, int
 
 }
 
-Headers::Base *extractFirstHeader(QByteArray &head)
+std::unique_ptr<KMime::Headers::Base> parseNextHeader(QByteArrayView &head)
 {
     int endOfFieldBody = 0;
-    auto header = extractHeader(head, 0, endOfFieldBody);
+    std::unique_ptr<KMime::Headers::Base> header(extractHeader(head, 0, endOfFieldBody));
     if (header) {
-        head.remove(0, endOfFieldBody + 1);
+        head = head.mid(endOfFieldBody + 1);
     } else {
-        head.clear();
+        head = {};
     }
 
     return header;
